pub trait SwhLabeledForwardGraph: SwhForwardGraph + SwhGraphWithProperties<Maps: Maps> {
type LabeledArcs<'arc>: Iterator<Item = UntypedEdgeLabel>
where Self: 'arc;
type LabeledSuccessors<'node>: IntoIterator<Item = (usize, Self::LabeledArcs<'node>)> + IntoFlattenedLabeledArcsIterator<UntypedEdgeLabel>
where Self: 'node;
// Required method
fn untyped_labeled_successors(
&self,
node_id: NodeId,
) -> Self::LabeledSuccessors<'_>;
// Provided method
fn labeled_successors(
&self,
node_id: NodeId,
) -> impl Iterator<Item = (usize, impl Iterator<Item = EdgeLabel>)> + IntoFlattenedLabeledArcsIterator<EdgeLabel> + '_ { ... }
}Required Associated Types
type LabeledArcs<'arc>: Iterator<Item = UntypedEdgeLabel> where Self: 'arc
type LabeledSuccessors<'node>: IntoIterator<Item = (usize, Self::LabeledArcs<'node>)> + IntoFlattenedLabeledArcsIterator<UntypedEdgeLabel> where Self: 'node
Required Methods
Sourcefn untyped_labeled_successors(
&self,
node_id: NodeId,
) -> Self::LabeledSuccessors<'_>
fn untyped_labeled_successors( &self, node_id: NodeId, ) -> Self::LabeledSuccessors<'_>
Return an IntoIterator over the successors of a node along with a list of labels
of each arc
Provided Methods
Sourcefn labeled_successors(
&self,
node_id: NodeId,
) -> impl Iterator<Item = (usize, impl Iterator<Item = EdgeLabel>)> + IntoFlattenedLabeledArcsIterator<EdgeLabel> + '_
fn labeled_successors( &self, node_id: NodeId, ) -> impl Iterator<Item = (usize, impl Iterator<Item = EdgeLabel>)> + IntoFlattenedLabeledArcsIterator<EdgeLabel> + '_
Return an IntoIterator over the successors of a node along with a list of labels
of each arc
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".