pub enum LabelNamesOrder {
Lexicographic,
LexicographicBase64,
}Expand description
How to sort label names in the produced graph. Defaults to Lexicographic.
Variants
Lexicographic
Sort label names in their lexicographic order, as for graphs compressed with Rust (2023-09-06 and newer)
LexicographicBase64
Sort label names in the lexicographic order of their base64-encoding, as for graphs compressed with Java (2022-12-07 and older)