pub struct MappedPermutation(/* private fields */);Expand description
A Permutation backed by a big-endian mmapped file
Implementations
Sourceimpl MappedPermutation
impl MappedPermutation
Sourcepub fn new_unchecked(perm: Mmap) -> Self
pub fn new_unchecked(perm: Mmap) -> Self
Creates a permutation
Sourcepub fn new(perm: Mmap) -> Result<Self>
pub fn new(perm: Mmap) -> Result<Self>
Creates a permutation, or returns an error in case the permutation is incorrect
Sourcepub fn load_unchecked(path: &Path) -> Result<Self>
pub fn load_unchecked(path: &Path) -> Result<Self>
Loads a permutation from disk and returns IO errors if any.
This is an alias for Self::load_unchecked_with_flags with MmapFlags::RANDOM_ACCESS
Sourcepub fn load_unchecked_with_flags(path: &Path, flags: MmapFlags) -> Result<Self>
pub fn load_unchecked_with_flags(path: &Path, flags: MmapFlags) -> Result<Self>
Loads a permutation from disk and returns IO errors if any.
Sourcepub fn load(num_nodes: usize, path: &Path) -> Result<Self>
pub fn load(num_nodes: usize, path: &Path) -> Result<Self>
Loads a permutation from disk, and returns errors in case of IO errors or incorrect permutations.
This is an alias for Self::load_with_flags with MmapFlags::RANDOM_ACCESS