AtomicFile

Struct AtomicFile 

pub struct AtomicFile { /* private fields */ }
Wrapper around File that writes to a temporary file and moves it to the path when closed

Implementations

Source

impl AtomicFile

pub fn create_new<P: AsRef<Path>>(path: P) -> Result<Self>

pub fn commit(self) -> Result<()>

pub fn rollback(self) -> Result<()>