pub enum VisitType {
Archive,
Misc,
Package,
Push,
Vcs,
VcsCheckout,
Unknown,
}Expand description
Lossy representation of visit types in the SWH data model
While the SWH data model precisely identifies the type of loader used to load content of an origin, swh-graph has to group them in order to fit in the compressed graph representation.
To get the exact visit type, you need to cross-reference with the columnar export
Variants
Archive
tar, zip, …
Misc
single content, patch, …
Package
npm, pypi, nixguix, …
Push
deposit, possibly coar-notify in the future
Vcs
git, hg, cvs, …
VcsCheckout
partial archiving of a repository (git-checkout, hg-checkout, svn-export)
Unknown
Either a type not categorized above, or graph is too old to support visit types
Implementations